==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/OnCollapsedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnCollapsedEventArgsDescription } from "./OnCollapsedEventArgsDescription";
/**
 * @hidden
 */
var OnCollapsedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OnCollapsedEventArgsDescriptionMetadata, _super);
    function OnCollapsedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnCollapsedEventArgsDescriptionMetadata.b = function (a) {
        if (OnCollapsedEventArgsDescriptionMetadata.a == null) {
            OnCollapsedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OnCollapsedEventArgsDescriptionMetadata.c(OnCollapsedEventArgsDescriptionMetadata.a);
        }
        if (a.k(OnCollapsedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(OnCollapsedEventArgsDescriptionMetadata.a);
    };
    OnCollapsedEventArgsDescriptionMetadata.c = function (a) {
    };
    OnCollapsedEventArgsDescriptionMetadata.d = function (a) {
        OnCollapsedEventArgsDescriptionMetadata.b(a);
        a.ac("OnCollapsedEventArgs", function () { return new OnCollapsedEventArgsDescription(); });
        a.ab("OnCollapsedEventArgs", OnCollapsedEventArgsDescriptionMetadata.a);
    };
    OnCollapsedEventArgsDescriptionMetadata.$t = markType(OnCollapsedEventArgsDescriptionMetadata, 'OnCollapsedEventArgsDescriptionMetadata');
    OnCollapsedEventArgsDescriptionMetadata.a = null;
    return OnCollapsedEventArgsDescriptionMetadata;
}(Base));
export { OnCollapsedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/OnCollapsedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnCollapsedEventArgsDescription } from "./OnCollapsedEventArgsDescription";
/**
 * @hidden
 */
var OnCollapsedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OnCollapsedEventArgsDescriptionMetadata, _super);
    function OnCollapsedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnCollapsedEventArgsDescriptionMetadata.b = function (a) {
        if (OnCollapsedEventArgsDescriptionMetadata.a == null) {
            OnCollapsedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OnCollapsedEventArgsDescriptionMetadata.c(OnCollapsedEventArgsDescriptionMetadata.a);
        }
        if (a.k(OnCollapsedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(OnCollapsedEventArgsDescriptionMetadata.a);
    };
    OnCollapsedEventArgsDescriptionMetadata.c = function (a) {
    };
    OnCollapsedEventArgsDescriptionMetadata.d = function (a) {
        OnCollapsedEventArgsDescriptionMetadata.b(a);
        a.ae("OnCollapsedEventArgs", function () { return new OnCollapsedEventArgsDescription(); });
        a.ad("OnCollapsedEventArgs", OnCollapsedEventArgsDescriptionMetadata.a);
    };
    OnCollapsedEventArgsDescriptionMetadata.$t = markType(OnCollapsedEventArgsDescriptionMetadata, 'OnCollapsedEventArgsDescriptionMetadata');
    OnCollapsedEventArgsDescriptionMetadata.a = null;
    return OnCollapsedEventArgsDescriptionMetadata;
}(Base));
export { OnCollapsedEventArgsDescriptionMetadata };
